Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(270)

Unified Diff: runtime/vm/object.h

Issue 2485993002: VM: Support bootstrapping core libraries from Kernel binaries instead of source. (Closed)
Patch Set: Done Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/object.h
diff --git a/runtime/vm/object.h b/runtime/vm/object.h
index e06c9b05e2e5c8342cf3d4de7fa84b557416e3e0..986ec302c4afd8929d4ebe1609fe2891fcd53f0d 100644
--- a/runtime/vm/object.h
+++ b/runtime/vm/object.h
@@ -525,8 +525,11 @@ class Object {
static void InitOnce(Isolate* isolate);
static void FinalizeVMIsolate(Isolate* isolate);
- // Initialize a new isolate either from source or from a snapshot.
- static RawError* Init(Isolate* isolate);
+ // Initialize a new isolate either from a Kernel IR, from source, or from a
+ // snapshot.
+ static RawError* Init(Isolate* isolate,
+ const uint8_t* kernel,
+ intptr_t kernel_length);
static void MakeUnusedSpaceTraversable(const Object& obj,
intptr_t original_size,
@@ -1503,8 +1506,8 @@ class Class : public Object {
// to a class after all classes have been loaded and finalized.
class UnresolvedClass : public Object {
public:
- RawLibraryPrefix* library_prefix() const {
- return raw_ptr()->library_prefix_;
+ RawObject* library_or_library_prefix() const {
+ return raw_ptr()->library_or_library_prefix_;
}
RawString* ident() const { return raw_ptr()->ident_; }
TokenPosition token_pos() const { return raw_ptr()->token_pos_; }
@@ -1515,12 +1518,12 @@ class UnresolvedClass : public Object {
return RoundedAllocationSize(sizeof(RawUnresolvedClass));
}
- static RawUnresolvedClass* New(const LibraryPrefix& library_prefix,
+ static RawUnresolvedClass* New(const Object& library_prefix,
const String& ident,
TokenPosition token_pos);
private:
- void set_library_prefix(const LibraryPrefix& library_prefix) const;
+ void set_library_or_library_prefix(const Object& library_prefix) const;
void set_ident(const String& ident) const;
void set_token_pos(TokenPosition token_pos) const;
@@ -3766,7 +3769,7 @@ class Library : public Object {
static RawLibrary* GetLibrary(intptr_t index);
static void InitCoreLibrary(Isolate* isolate);
- static void InitNativeWrappersLibrary(Isolate* isolate);
+ static void InitNativeWrappersLibrary(Isolate* isolate, bool is_kernel_file);
static RawLibrary* AsyncLibrary();
static RawLibrary* ConvertLibrary();

Powered by Google App Engine
This is Rietveld 408576698